==> haskell-safesemaphore-0.10.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safesemaphore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 SafeSemaphore
version:              0.10.1
visibility:           public
id:                   SafeSemaphore-0.10.1-CuVbWtmVdcWIkzZ4mM85OG
key:                  SafeSemaphore-0.10.1-CuVbWtmVdcWIkzZ4mM85OG
license:              BSD-3-Clause
maintainer:           Chris Kuklewicz <haskell@list.mightyreason.com>
author:               Chris Kuklewicz <haskell@list.mightyreason.com>
homepage:             https://github.com/ChrisKuklewicz/SafeSemaphore
synopsis:             Much safer replacement for QSemN, QSem, and SampleVar
description:
    This provides a much safer semaphore than the QSem, QSemN, SampleVar in base.
    Those base modules are not exception safe and can be broken by killThread.
    See <https://github.com/ChrisKuklewicz/SafeSemaphore> for more details.

category:             Concurrency
abi:                  d6f8fa232608dac1494613572b7d2fa0
exposed:              True
exposed-modules:
    Control.Concurrent.FairRWLock Control.Concurrent.MSampleVar
    Control.Concurrent.MSem Control.Concurrent.MSemN
    Control.Concurrent.MSemN2 Control.Concurrent.SSem
    Control.Concurrent.STM.SSem

hidden-modules:       Control.Concurrent.STM.SSemInternals
import-dirs:          /usr/lib/ghc-9.0.1/site-local/SafeSemaphore-0.10.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/SafeSemaphore-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/SafeSemaphore-0.10.1
hs-libraries:         HSSafeSemaphore-0.10.1-CuVbWtmVdcWIkzZ4mM85OG
depends:              base-4.15.0.0 containers-0.6.4.1 stm-2.5.0.0
haddock-interfaces:
    /usr/share/doc/haskell-safesemaphore/html/SafeSemaphore.haddock

haddock-html:         /usr/share/doc/haskell-safesemaphore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safesemaphore-0.10.1-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safesemaphore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 SafeSemaphore
version:              0.10.1
visibility:           public
id:                   SafeSemaphore-0.10.1-ECg1M2AFTOM2YcrBRcD0t2
key:                  SafeSemaphore-0.10.1-ECg1M2AFTOM2YcrBRcD0t2
license:              BSD-3-Clause
maintainer:           Chris Kuklewicz <haskell@list.mightyreason.com>
author:               Chris Kuklewicz <haskell@list.mightyreason.com>
homepage:             https://github.com/ChrisKuklewicz/SafeSemaphore
synopsis:             Much safer replacement for QSemN, QSem, and SampleVar
description:
    This provides a much safer semaphore than the QSem, QSemN, SampleVar in base.
    Those base modules are not exception safe and can be broken by killThread.
    See <https://github.com/ChrisKuklewicz/SafeSemaphore> for more details.

category:             Concurrency
abi:                  889b4919768e6f15ad3a2968028fd237
exposed:              True
exposed-modules:
    Control.Concurrent.FairRWLock Control.Concurrent.MSampleVar
    Control.Concurrent.MSem Control.Concurrent.MSemN
    Control.Concurrent.MSemN2 Control.Concurrent.SSem
    Control.Concurrent.STM.SSem

hidden-modules:       Control.Concurrent.STM.SSemInternals
import-dirs:          /usr/lib/ghc-9.0.2/site-local/SafeSemaphore-0.10.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/SafeSemaphore-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/SafeSemaphore-0.10.1
hs-libraries:         HSSafeSemaphore-0.10.1-ECg1M2AFTOM2YcrBRcD0t2
depends:              base-4.15.1.0 containers-0.6.4.1 stm-2.5.0.0
haddock-interfaces:
    /usr/share/doc/haskell-safesemaphore/html/SafeSemaphore.haddock

haddock-html:         /usr/share/doc/haskell-safesemaphore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
